@@ -50,7 +50,7 @@ class UserClient(BaseClient):
         # self.proxy: Proxy = self.storage.session.proxy and self.storage.session.proxy.dict()
 
     async def start(self, use_qr: bool = False, except_ids: list[int] = None):
-        if not self.bot.is_connected:
+        if self.bot and not self.bot.is_connected:
             await self.bot.start()
         await super().start(use_qr, except_ids)
         # await self.send("/start", self.bot.uid)
@@ -84,7 +84,7 @@ class UserClient(BaseClient):
                 return v
         return 2
 
-    async def authorize(self, sent_code: SentCode = None) -> User:
+    async def authorize(self, sent_code: SentCode = None) -> User | None:
         sent_code_desc = {
             enums.SentCodeType.APP: "Telegram app",
             enums.SentCodeType.SMS: "SMS",
@@ -134,8 +134,8 @@ class UserClient(BaseClient):
                         except BadRequest as e:
                             await self.send(e.MESSAGE)
                             self.password = None
-            else:
-                raise Exception("User does not sent code")
+                else:
+                    raise Exception("User does not sent code")
             if isinstance(signed_in, User):
                 await self.send("✅")
                 await self.storage.save()
@@ -143,6 +143,7 @@ class UserClient(BaseClient):
 
             if not signed_in:
                 await self.receive("No registered such phone number")
+        return None
 
     async def session_update(self, dc: int):
         await self.session.stop()
@@ -164,12 +165,10 @@ class UserClient(BaseClient):
 
 
 async def main():
-    from x_auth import models
     from x_model import init_db
+    from pyro_client.loader import TORM
 
-    from pyro_client.loader import PG_DSN
-
-    _ = await init_db(PG_DSN, models, True)
+    _ = await init_db(TORM, True)
 
     logging.basicConfig(level=logging.INFO)
 
